@@ -1,11 +1,5 @@
 # __main__.py
 
-import sys
-import argparse
-
-import pandas as pd
-
-
 def main():
     print("Project is on the way to update this feature...,\nThank you all for your support")
     return
