@@ -2,7 +2,7 @@ from preprocessing_pgp.phone.const import (
     SUB_PHONE_11NUM,
     SUB_TELEPHONE_10NUM,
     DICT_4_SUB_PHONE,
-    DICT_4_SUB_TELEPHONE,
+    DICT_4_SUB_TELEPHONE
 )
 
 
@@ -42,9 +42,11 @@ def convert_phone_region(old_region: str) -> str:
     """
     if old_region[:2] in SUB_TELEPHONE_10NUM:
         return DICT_4_SUB_TELEPHONE[old_region[:2]] + old_region[2:]
-    elif old_region[:3] in SUB_TELEPHONE_10NUM:
+
+    if old_region[:3] in SUB_TELEPHONE_10NUM:
         return DICT_4_SUB_TELEPHONE[old_region[:3]] + old_region[3:]
-    elif old_region[:4] in SUB_TELEPHONE_10NUM:
+
+    if old_region[:4] in SUB_TELEPHONE_10NUM:
         return DICT_4_SUB_TELEPHONE[old_region[:4]] + old_region[4:]
-    else:
-        return None
+
+    return None
