@@ -1,14 +1,10 @@
 """
 Module to convert old type phones to their new type
 """
-import multiprocessing as mp
 from time import time
 
 import pandas as pd
-import numpy as np
-from unidecode import unidecode
 from tqdm import tqdm
-from halo import Halo
 
 from preprocessing_pgp.phone.const import (
     SUB_PHONE_10NUM,
@@ -19,7 +15,6 @@ from preprocessing_pgp.phone.const import (
 from preprocessing_pgp.phone.utils import basic_phone_preprocess
 from preprocessing_pgp.utils import (
     parallelize_dataframe,
-    sep_display
 )
 from preprocessing_pgp.phone.converter import (
     convert_mobi_phone,
@@ -36,12 +31,6 @@ tqdm.pandas()
 
 
 # ? CHECK & EXTRACT FOR VALID PHONE
-@Halo(
-    text='Checking & Converting Valid Phone',
-    color='cyan',
-    spinner='dots7',
-    text_color='magenta'
-)
 def extract_valid_phone(
     phones: pd.DataFrame,
     phone_col: str = "phone",
@@ -64,27 +53,29 @@ def extract_valid_phone(
     pd.DataFrame
         The DataFrame with converted phone column and check if valid or not
     """
+    if phones.empty:
+        return phones
     # * Split na phone
     na_phones = phones[phones[phone_col].isna()]
-    #! Prevent override the origin DF
+    # ! Prevent override the origin DF
     f_phones = phones[phones[phone_col].notna()]
     origin_cols = f_phones.columns
 
     # ? Preprocess phone with basic phone string clean up
-    f_phones["clean_phone"] = f_phones[phone_col].apply(
+    f_phones["phone_clean"] = f_phones[phone_col].apply(
         basic_phone_preprocess)
 
     if print_info:
         print(
-            f"# OF PHONE CLEAN : {f_phones.query(f'clean_phone != {phone_col}').shape[0]}",
+            f"# OF PHONE CLEAN : {f_phones.query(f'phone_clean != {phone_col}').shape[0]}",
             end="\n\n",
         )
 
         # print("Sample of non-clean phones:")
-        # print(f_phones.query(f"clean_phone != {phone_col}"), end="\n\n\n")
+        # print(f_phones.query(f"phone_clean != {phone_col}"), end="\n\n\n")
 
     # ? Calculate the phone length for further preprocessing
-    f_phones["phone_length"] = f_phones["clean_phone"].map(
+    f_phones["phone_length"] = f_phones["phone_clean"].map(
         lambda x: len(str(x))
     )
 
@@ -93,7 +84,7 @@ def extract_valid_phone(
 
     # * Length 10 - New
     mask_valid_new_sub_phone = (f_phones["phone_length"] == 10) & (
-        f_phones["clean_phone"].str[:3].isin(SUB_PHONE_10NUM)
+        f_phones["phone_clean"].str[:3].isin(SUB_PHONE_10NUM)
     )
     f_phones.loc[
         mask_valid_new_sub_phone,
@@ -108,7 +99,7 @@ def extract_valid_phone(
 
     # * Length 11 - Old
     mask_valid_old_sub_phone = (f_phones["phone_length"] == 11) & (
-        f_phones["clean_phone"].str[:4].isin(SUB_PHONE_11NUM)
+        f_phones["phone_clean"].str[:4].isin(SUB_PHONE_11NUM)
     )
     f_phones.loc[
         mask_valid_old_sub_phone,
@@ -121,13 +112,11 @@ def extract_valid_phone(
             end="\n\n\n",
         )
 
-    f_phones = f_phones.reset_index(drop=True)
-
     # ? Correct phone numbers with old phone number format.
-    mask_old_phone_format = f_phones["is_old_mobi"] == True
+    mask_old_phone_format = f_phones["is_old_mobi"]
 
     f_phones.loc[mask_old_phone_format, "phone_convert"] = f_phones.loc[
-        mask_old_phone_format, "clean_phone"
+        mask_old_phone_format, "phone_clean"
     ].map(convert_mobi_phone)
 
     if print_info:
@@ -144,8 +133,8 @@ def extract_valid_phone(
     mask_valid_new_tele_phone = (
         (f_phones["phone_length"] == 11)
         & (
-            (f_phones["clean_phone"].str[:3].isin(SUB_TELEPHONE_11NUM))
-            | (f_phones["clean_phone"].str[:4].isin(SUB_TELEPHONE_11NUM))
+            (f_phones["phone_clean"].str[:3].isin(SUB_TELEPHONE_11NUM))
+            | (f_phones["phone_clean"].str[:4].isin(SUB_TELEPHONE_11NUM))
         )
         & (f_phones["is_mobi"].isna())
     )
@@ -158,9 +147,9 @@ def extract_valid_phone(
     mask_valid_old_tele_phone = (
         (f_phones["phone_length"] == 10)
         & (
-            (f_phones["clean_phone"].str[:3].isin(SUB_TELEPHONE_10NUM))
-            | (f_phones["clean_phone"].str[:2].isin(SUB_TELEPHONE_10NUM))
-            | (f_phones["clean_phone"].str[:4].isin(SUB_TELEPHONE_10NUM))
+            (f_phones["phone_clean"].str[:3].isin(SUB_TELEPHONE_10NUM))
+            | (f_phones["phone_clean"].str[:2].isin(SUB_TELEPHONE_10NUM))
+            | (f_phones["phone_clean"].str[:4].isin(SUB_TELEPHONE_10NUM))
         )
         & (f_phones["is_mobi"].isna())
     )
@@ -171,13 +160,13 @@ def extract_valid_phone(
 
     # ? Convert head phone of region from old to new
 
-    mask_old_region_phone = f_phones["is_old_landline"] == True
+    mask_old_region_phone = f_phones["is_old_landline"]
 
     if print_info:
         print(f"# OF OLD REGION PHONE : {mask_old_region_phone.sum()}")
 
     f_phones.loc[mask_old_region_phone, "phone_convert"] = f_phones.loc[
-        mask_old_region_phone, "clean_phone"
+        mask_old_region_phone, "phone_clean"
     ].map(convert_phone_region)
 
     # if print_info:
@@ -188,6 +177,7 @@ def extract_valid_phone(
     # ? Filling NaNs in indicator columns
 
     fill_cols = [
+        "phone_clean",
         "is_phone_valid",
         "is_mobi",
         "is_new_mobi",
@@ -202,7 +192,7 @@ def extract_valid_phone(
     f_phones.loc[
         f_phones["is_phone_valid"] & f_phones["phone_convert"].isna(
         ), "phone_convert"
-    ] = f_phones["clean_phone"]
+    ] = f_phones["phone_clean"]
 
     if print_info:
         print(
@@ -216,8 +206,8 @@ def extract_valid_phone(
 
         # print("Sample of invalid phones:", end="\n\n")
 
-    f_phones.drop(phone_col, axis=1, inplace=True)
-    f_phones.rename(columns={"clean_phone": phone_col}, inplace=True)
+    # f_phones.drop(phone_col, axis=1, inplace=True)
+    # f_phones.rename(columns={"phone_clean": phone_col}, inplace=True)
     f_phones = f_phones[[*origin_cols, *fill_cols, 'phone_convert']]
     # if print_info:
     #     print(f_phones[~f_phones["is_phone_valid"]].head(10))
@@ -271,7 +261,8 @@ def extract_valid_phone(
 def process_convert_phone(
     data: pd.DataFrame,
     phone_col: str = 'phone',
-    n_cores: int = 1
+    n_cores: int = 1,
+    logging_info: bool = True
 ) -> pd.DataFrame:
     """
     Converting valid phone to new phone type
@@ -301,6 +292,8 @@ def process_convert_phone(
     phone_data = data[[phone_col]]
 
     # * Validate and convert phone
+    if logging_info:
+        print(">>> Converting phones: ")
     start_time = time()
 
     converted_data = parallelize_dataframe(
@@ -313,21 +306,23 @@ def process_convert_phone(
 
     convert_time = time()-start_time
 
-    print(
-        f"Converting phones takes {int(convert_time)//60}m{int(convert_time)%60}s")
-    sep_display()
+    if logging_info:
+        print(f"{int(convert_time)//60}m{int(convert_time)%60}s")
 
     # * Concat with original cols
     new_cols = [
+        'phone_clean',
         'is_phone_valid',
         'phone_type',
         'phone_convert',
         'phone_vendor',
         'tail_phone_type'
     ]
+    converted_data = converted_data[new_cols]
+
     converted_data = pd.concat([
         data[orig_cols],
-        converted_data[new_cols]
+        converted_data
     ], axis=1)
 
     return converted_data
